from sys import argv


def box_borders(func):
    def wrapper(txt: str):
        print(" " + "_" * (len(txt) + 1))
        print("/" + "_" * len(txt) + "/|")
        print("|" + " " * len(txt) + "||")
        func("|" + txt + "||")
        print("|" + "_" * len(txt) + "|/")

    return wrapper


@box_borders
def print_console(txt):
    print(txt)


def run():
    try:
        message = argv[1]
    except IndexError:
        message = "You have to pass at least one word!"

    print_console(message)



from distutils.core import setup
from boxie.version import __version__

setup(
    name="boxie",
    version=__version__,
    author="UltiRequiem",
    author_email="eliaz.bobadilladev@gmail.com",
    url="https://github.com/UltiRequiem/boxie",
    include_package_data=True,
    license="MIT",
    scripts=["./bin/boxie"],
    packages=["boxie"],
)
